@@ -5,7 +5,7 @@ use warnings;
 use v5.16;
 use base 'TAP::Formatter::File';
 use Data::Dumper;
-our $VERSION = '0.3.0_5';
+our $VERSION = '0.3.0_6';
 
 use TAP::Formatter::GitHubActions::Error;
 use TAP::Formatter::GitHubActions::ErrorGroup;
@@ -130,7 +130,7 @@ sub _output_report_notice {
 
   my $file_marker_line = TAP::Formatter::GitHubActions::Utils::log_annotation_line(
     type => 'notice',
-    test => $test,
+    filename => $test,
     line => 1,
     title => 'More details',
     body => "See the full report in: $workflow_url"
@@ -201,7 +201,7 @@ sub _dump_test_parser {
   $self->_output($_->as_gha_summary_for($test)) for (@error_groups);
 
   # Skip if not running in GitHub Actions
-  next unless $RUNNING_IN_GHA;
+  return unless $RUNNING_IN_GHA;
 
   # Write full report on GHA Step Summary [2]
   open(my $summary_fd, '>>', $ENV{GITHUB_STEP_SUMMARY}) or die "Unable to open " . $ENV{GITHUB_STEP_SUMMARY} . ": $!" if $RUNNING_IN_GHA;
